@@ -16,7 +16,6 @@ FeatureImportanceMethod = R6Class(
 		resampling = NULL,
 		#' @field resample_result ([mlr3::ResampleResult]) of the original `learner` and `task`, used for baseline scores.
 		resample_result = NULL,
-		# TODO: list of features, for grouped importance
 		#' @field features (`character`: `NULL`) Features of interest. By default, importances will be computed for each feature
 		#'   in `task`, but optionally this can be restricted to at least one feature. Ignored if `groups` is specified.
 		features = NULL,
@@ -87,11 +86,24 @@ FeatureImportanceMethod = R6Class(
 			} else {
 				# Clone the resampling to avoid instantiating the resampling in the user's workspace
 				resampling = mlr3::assert_resampling(resampling)$clone()
+
+				# A pretrained learner requires a user-provided instantiated resampling
+				# to define the test set explicitly. Auto-instantiation would pick an
+				# arbitrary split unrelated to how the learner was trained.
+				if (!is.null(learner$model) && !resampling$is_instantiated) {
+					cli::cli_abort(c(
+						"A pre-trained {.cls Learner} requires an instantiated {.cls Resampling}",
+						i = "Instantiate the {.cls Resampling} before passing it, e.g. {.code rsmp(\"holdout\")$instantiate(task)}"
+					))
+				}
 			}
 			if (!resampling$is_instantiated) {
 				resampling$instantiate(task)
 			}
 			self$resampling = resampling
+
+			# Check pretrained learner compatibility (multi-fold with pretrained learner)
+			assert_pretrained(self$learner, self$task, self$resampling)
 		},
 
 		#' @description
@@ -118,43 +130,90 @@ FeatureImportanceMethod = R6Class(
 		#'   These methods are model-agnostic and rely on suitable `resampling`s, e.g. subsampling with 15 repeats for `"nadeau_bengio"`.
 		#'   See details.
 		#' @param conf_level (`numeric(1)`: `0.95`) Confidence level to use for confidence interval construction when `ci_method != "none"`.
+		#' @param alternative (`character(1)`: `"two.sided"`) Type of alternative hypothesis for statistical tests.
+		#'   `"greater"` tests H0: importance <= 0 vs H1: importance > 0 (one-sided).
+		#'   `"two.sided"` tests H0: importance = 0 vs H1: importance != 0.
+		#'   Only used when `ci_method != "none"`.
 		#' @param ... Additional arguments passed to specialized methods, if any.
 		#' @return ([data.table][data.table::data.table]) Aggregated importance scores with columns `"feature"`, `"importance"`,
-		#' and depending on `ci_method` also `"se"`, `"conf_lower"`, `"conf_upper"`.
+		#' and depending on `ci_method` also `"se"`, `"statistic"`, `"p.value"`, `"conf_lower"`, `"conf_upper"`.
 		#'
 		#' @details
-		#' Variance estimates for importance scores are biased due to the resampling procedure. Molnar et al. (2023) suggest to use
-		#' the variance correction factor proposed by Nadeau & Bengio (2003) of n2/n1, where n2 and n1 are the sizes of the test- and train set, respectively.
-		#' This should then be combined with approx. 15 iterations of either bootstrapping or subsampling.
 		#'
-		#' The use of bootstrapping in this context can lead to problematic information leakage when combined with learners
-		#' that perform bootstrapping themselves, e.g., Random Forest learners.
-		#' In such cases, observations may be used as train- and test instances simultaneously, leading to erroneous performance estimates.
+		#' ## Confidence Interval Methods
 		#'
-		#' An approach leading to still imperfect, but improved variance estimates could be:
+		#' The parametric methods (`"raw"`, `"nadeau_bengio"`) return standard error (`se`),
+		#' test statistic (`statistic`), p-value (`p.value`), and confidence bounds
+		#' (`conf_lower`, `conf_upper`). The `"quantile"` method returns only lower and upper bounds.
+		#'
+		#' **`"raw"`: Uncorrected (!) t-test**
+		#' Uses a standard t-test assuming independence of resampling iterations.
+		#' - SE = sd(resampling scores) / sqrt(n_iters)
+		#' - Test statistic: t = importance / SE with df = n_iters - 1
+		#' - P-value: From t-distribution (one-sided or two-sided depending on `alternative`)
+		#' - CIs: importance +/- qt(1 - alpha, df) * SE
+		#'
+		#' **Warning**: These CIs are too narrow because resampling iterations share
+		#' training data and are not independent.
+		#' This method is included only for demonstration purposes.
+		#'
+		#' **`"nadeau_bengio"`: Corrected t-test**
+		#' Applies the Nadeau & Bengio (2003) correction to account for correlation between
+		#' resampling iterations due to overlapping training sets.
+		#' - Correction factor: (1/n_iters + n_test/n_train)
+		#' - SE = sqrt(correction_factor * var(resampling scores))
+		#' - Test statistic and p-value: As in `"raw"`, but with corrected SE
+		#'
+		#' Recommended with bootstrap or subsampling (>= 10 iterations).
+		#'
+
+		#' **`"quantile"`: Non-parametric empirical method**
+		#' Uses the resampling distribution directly without parametric assumptions.
+		#' - CIs: Empirical quantiles of the resampling distribution
+		#'
+		#' This method does not provide `se`, `statistic`, or `p.value`.
+		#'
+		#' ## Method-Specific CI Methods
+		#'
+		#' Some importance methods provide additional CI methods tailored to their approach:
+		#'
+		#' - **[CFI]**: Adds `"cpi"` (Conditional Predictive Impact), which uses observation-wise
+		#'   loss differences with holdout resampling. Supports t-test, Wilcoxon, Fisher permutation,
+		#'   and binomial tests. See Watson & Wright (2021).
+		#'
+		#' ## Practical Recommendations
+		#'
+		#' Variance estimates for importance scores are biased due to the resampling procedure.
+		#' Molnar et al. (2023) suggest using the Nadeau & Bengio correction with approximately
+		#' 15 iterations of subsampling.
+		#'
+		#' Bootstrapping can cause information leakage with learners that bootstrap internally
+		#' (e.g., Random Forests), as observations may appear in both train and test sets.
+		#' Prefer subsampling in such cases:
 		#'
 		#' ```r
 		#' PFI$new(
 		#'   task = sim_dgp_interactions(n = 1000),
 		#'   learner = lrn("regr.ranger", num.trees = 100),
 		#'   measure = msr("regr.mse"),
-		#'   # Subsampling instead of bootstrapping due to RF
 		#'   resampling = rsmp("subsampling", repeats = 15),
-		#'   n_repeats = 5
+		#'   n_repeats = 20
 		#' )
 		#' ```
 		#'
-		#' `n_repeats = 5` in this context only improves the stability of the PFI estimate within the resampling iteration, whereas `rsmp("subsampling", repeats = 15)`
-		#' is used to account for learner variance and necessitates variance correction.
+		#' The `"nadeau_bengio"` correction was validated for PFI; its use with other methods
+		#' like LOCO or SAGE is experimental.
 		#'
-		#' This approach can in principle also be applied to `CFI` and `RFI`, but beware that a conditional sample such as [ConditionalARFSampler] also needs to be trained on data,
-		#' which would need to be taken account by the variance estimation method.
-		#' Analogously, the `"nadeau_bengio"` correction was recommended for the use with [PFI] by Molnar et al., so its use with other methods like [LOCO] or [SAGE] is experimental.
-		#'
-		#' Note that even if `measure` uses an `aggregator` function that is not the mean, variance estimation currently will always use [mean()] and [var()].
+		#' @param p_adjust (`character(1)`: `"none"`) Method for p-value adjustment for multiple comparisons.
+		#'   Accepts any method supported by [stats::p.adjust.methods], e.g. `"holm"`, `"bonferroni"`, `"BH"`, `"none"`.
+		#'   Applied to p-values from `"raw"` and `"nadeau_bengio"` methods.
+		#'   When `"bonferroni"`, confidence intervals are also adjusted (alpha/k).
+		#'   For other correction methods (e.g. `"holm"`, `"BH"`), only p-values are adjusted;
+		#'   confidence intervals remain at the nominal `conf_level` because these sequential/adaptive
+		#'   procedures do not have a clean per-comparison alpha for CI construction.
 		#'
 		#' @references
-		#' `r print_bib("nadaeu_2003")`
+		#' `r print_bib("nadeau_2003")`
 		#' `r print_bib("molnar_2023")`
 		#'
 		importance = function(
@@ -162,6 +221,8 @@ FeatureImportanceMethod = R6Class(
 			standardize = FALSE,
 			ci_method = c("none", "raw", "nadeau_bengio", "quantile"),
 			conf_level = 0.95,
+			alternative = c("two.sided", "greater"),
+			p_adjust = "none",
 			...
 		) {
 			if (is.null(private$.scores)) {
@@ -171,12 +232,23 @@ FeatureImportanceMethod = R6Class(
 				return(invisible(NULL))
 			}
 
+			# Catch unknown arguments that were not consumed by subclass methods
+			if (...length() > 0) {
+				dots = list(...)
+				cli::cli_abort(c(
+					"Unknown argument{?s}: {.arg {names(dots)}}.",
+					i = "These arguments are not used by {.fun $importance} with {.code ci_method = \"{ci_method}\"}."
+				))
+			}
+
 			# Validate ci_method
 			if (length(ci_method) > 1) {
 				ci_method = ci_method[1]
 			}
 			checkmate::assert_choice(ci_method, choices = private$.ci_methods)
 			checkmate::assert_number(conf_level, lower = 0, upper = 1)
+			checkmate::assert_choice(p_adjust, choices = stats::p.adjust.methods)
+			alternative = match.arg(alternative)
 
 			# Get aggregator and scores
 			aggregator = self$measure$aggregator %||% mean
@@ -191,15 +263,24 @@ FeatureImportanceMethod = R6Class(
 			agg_importance = switch(
 				ci_method,
 				none = importance_none(scores, aggregator, conf_level),
-				raw = importance_raw(scores, aggregator, conf_level, self$resample_result$iters),
+				raw = importance_raw(
+					scores,
+					aggregator,
+					conf_level,
+					alternative,
+					self$resample_result$iters,
+					p_adjust = p_adjust
+				),
 				nadeau_bengio = importance_nadeau_bengio(
 					scores,
 					aggregator,
 					conf_level,
+					alternative,
 					self$resampling,
-					self$resample_result$iters
+					self$resample_result$iters,
+					p_adjust = p_adjust
 				),
-				quantile = importance_quantile(scores, aggregator, conf_level),
+				quantile = importance_quantile(scores, aggregator, conf_level, alternative),
 				cli::cli_abort(c(
 					"Variance method {.val {ci_method}} not found.",
 					i = "Available methods: {.val {private$.ci_methods}}"
