@@ -15,7 +15,7 @@ PerturbationImportance = R6Class(
 		#' @param task,learner,measure,resampling,features,groups Passed to [FeatureImportanceMethod].
 		#' @param sampler ([FeatureSampler]) Sampler to use for feature perturbation.
 		#' @param relation (`character(1)`: `"difference"`) How to relate perturbed and baseline scores. Can also be `"ratio"`.
-		#' @param n_repeats (`integer(1)`: `1L`) Number of permutation/conditional sampling iterations. Can be overridden in `$compute()`.
+		#' @param n_repeats (`integer(1)`: `30L`) Number of permutation/conditional sampling iterations. Can also be overridden in `$compute()`.
 		#' @param batch_size (`integer(1)` | `NULL`: `NULL`) Maximum number of rows to predict at once. When `NULL`, predicts all `test_size * n_repeats` rows in one call. Use smaller values to reduce memory usage at the cost of more prediction calls. Can be overridden in `$compute()`.
 		initialize = function(
 			task,
@@ -26,7 +26,7 @@ PerturbationImportance = R6Class(
 			groups = NULL,
 			sampler = NULL,
 			relation = "difference",
-			n_repeats = 1L,
+			n_repeats = 30L,
 			batch_size = NULL
 		) {
 			super$initialize(
@@ -71,15 +71,25 @@ PerturbationImportance = R6Class(
 
 		#' @description
 		#' Get aggregated importance scores.
-		#' Extends the base `$importance()` method to support the additional `"cpi"` ci_method.
+		#' Extends the base `$importance()` method to support `ci_method = "cpi"`.
+		#' For details, see [CFI], which is the only sub-method for which it is known to be valid.
 		#' @param relation (`character(1)`) How to relate perturbed scores to originals ("difference" or "ratio"). If `NULL`, uses stored parameter value.
 		#' @param standardize (`logical(1)`: `FALSE`) If `TRUE`, importances are standardized by the highest score so all scores fall in `[-1, 1]`.
 		#' @param ci_method (`character(1)`: `"none"`) Variance estimation method. In addition to base methods (`"none"`, `"raw"`, `"nadeau_bengio"`, `"quantile"`),
 		#'   perturbation methods support `"cpi"` (Conditional Predictive Impact).
 		#'   CPI is specifically designed for [CFI] with knockoff samplers and uses one-sided hypothesis tests.
 		#' @param conf_level (`numeric(1)`: `0.95`) Confidence level for confidence intervals when `ci_method != "none"`.
+		#' @param alternative (`character(1)`: `"two.sided"`) Type of alternative hypothesis for statistical tests.
+		#'   `"greater"` tests H0: importance <= 0 vs H1: importance > 0 (one-sided).
+		#'   `"two.sided"` tests H0: importance = 0 vs H1: importance != 0.
 		#' @param test (`character(1)`: `"t"`) Test to use for CPI. One of `"t"`, `"wilcoxon"`, `"fisher"`, or `"binomial"`. Only used when `ci_method = "cpi"`.
 		#' @param B (`integer(1)`: `1999`) Number of replications for Fisher test. Only used when `ci_method = "cpi"` and `test = "fisher"`.
+		#' @param p_adjust (`character(1)`: `"none"`) Method for p-value adjustment for multiple comparisons.
+		#'   Accepts any method supported by [stats::p.adjust.methods], e.g. `"holm"`, `"bonferroni"`, `"BH"`, `"none"`.
+		#'   When `"bonferroni"`, confidence intervals are also adjusted (alpha/k).
+		#'   For other correction methods (e.g. `"holm"`, `"BH"`), only p-values are adjusted;
+		#'   confidence intervals remain at the nominal `conf_level` because these sequential/adaptive
+		#'   procedures do not have a clean per-comparison alpha for CI construction.
 		#' @param ... Additional arguments passed to the base method.
 		#' @return ([data.table][data.table::data.table]) Aggregated importance scores.
 		importance = function(
@@ -87,14 +97,17 @@ PerturbationImportance = R6Class(
 			standardize = FALSE,
 			ci_method = c("none", "raw", "nadeau_bengio", "quantile", "cpi"),
 			conf_level = 0.95,
+			alternative = c("two.sided", "greater"),
 			test = c("t", "wilcoxon", "fisher", "binomial"),
 			B = 1999,
+			p_adjust = "none",
 			...
 		) {
 			# Handle CPI separately, delegate rest to parent
 			if (length(ci_method) > 1) {
 				ci_method = ci_method[1]
 			}
+			alternative = match.arg(alternative)
 
 			if (ci_method == "cpi") {
 				# CPI requires special handling
@@ -120,7 +133,9 @@ PerturbationImportance = R6Class(
 				test = match.arg(test)
 				agg_importance = importance_cpi(
 					conf_level = conf_level,
+					alternative = alternative,
 					test = test,
+					p_adjust = p_adjust,
 					B = B,
 					method_obj = self
 				)
@@ -134,6 +149,8 @@ PerturbationImportance = R6Class(
 					standardize = standardize,
 					ci_method = ci_method,
 					conf_level = conf_level,
+					alternative = alternative,
+					p_adjust = p_adjust,
 					...
 				)
 			}
@@ -141,12 +158,12 @@ PerturbationImportance = R6Class(
 	),
 
 	private = list(
-		.compute_baseline = function(store_models = TRUE, store_backends = TRUE) {
-			self$resample_result = resample(
-				self$task,
-				self$learner,
-				self$resampling,
-				store_models = store_models,
+		.compute_baseline = function(store_backends = TRUE) {
+			self$resample_result = assemble_rr(
+				task = self$task,
+				learner = self$learner,
+				resampling = self$resampling,
+				store_models = TRUE,
 				store_backends = store_backends
 			)
 			# Prepare baseline scores
@@ -337,16 +354,16 @@ PerturbationImportance = R6Class(
 #' `r print_bib("fisher_2019")`
 #' `r print_bib("strobl_2008")`
 #'
-#' @examplesIf requireNamespace("ranger", quietly = TRUE) && requireNamespace("mlr3learners", quietly = TRUE)
+#' @examples
 #' library(mlr3)
-#' library(mlr3learners)
 #'
 #' task <- sim_dgp_correlated(n = 500)
 #'
 #' pfi <- PFI$new(
 #'   task = task,
-#'   learner = lrn("regr.ranger", num.trees = 10),
-#'   measure = msr("regr.mse")
+#'   learner = lrn("regr.rpart"),
+#'   measure = msr("regr.mse"),
+#' n_repeats = 5
 #' )
 #' pfi$compute()
 #' pfi$importance()
@@ -366,7 +383,7 @@ PFI = R6Class(
 			features = NULL,
 			groups = NULL,
 			relation = "difference",
-			n_repeats = 1L,
+			n_repeats = 30L,
 			batch_size = NULL
 		) {
 			super$initialize(
@@ -414,19 +431,52 @@ PFI = R6Class(
 #'
 #' @description Implementation of CFI using modular sampling approach
 #'
-#' @references `r print_bib("blesch_2025")`
+#' @details
 #'
-#' @examplesIf requireNamespace("ranger", quietly = TRUE) && requireNamespace("mlr3learners", quietly = TRUE) && requireNamespace("arf", quietly = TRUE)
+#' CFI replaces feature values with conditional samples from the distribution of
+#' the feature given the other features. Any [ConditionalSampler] or [KnockoffSampler] can be used.
+#'
+#' ## Statistical Inference
+#'
+#' Two approaches for statistical inference are primarily supported via
+#' `$importance(ci_method = "cpi")`:
+#'
+#' - **CPI** (Watson & Wright, 2021): The original Conditional Predictive Impact method,
+#'   designed for use with knockoff samplers ([KnockoffGaussianSampler]).
+#'
+#' - **cARFi** (Blesch et al., 2025): CFI with ARF-based conditional sampling
+#'   ([ConditionalARFSampler]), using the same CPI inference framework.
+#'
+#' Both require a decomposable measure (e.g., MSE) and out-of-sample evaluation.
+#' CPI inference is guaranteed to be valid with holdout (a single train/test split).
+#' With cross-validation, test observations are i.i.d. but models are fit on
+#' overlapping training data, which may affect inference coverage. With bootstrap
+#' or subsampling, both non-i.i.d. test observations and overlapping training data
+#' can be an issue. See `vignette("inference", package = "xplainfi")` for details.
+#'
+#' Available tests: `"t"` (t-test), `"wilcoxon"` (signed-rank), `"fisher"` (permutation),
+#' `"binomial"` (sign test). The Fisher test is recommended.
+#'
+#' Method-agnostic inference methods (`"raw"`, `"nadeau_bengio"`, `"quantile"`) are also
+#' available; see [FeatureImportanceMethod] for details.
+#'
+#' For a comprehensive overview of inference methods including usage examples,
+#' see `vignette("inference", package = "xplainfi")`.
+#'
+#' @references `r print_bib("watson_2021", "blesch_2025")`
+#'
+#' @examples
 #' library(mlr3)
-#' library(mlr3learners)
 #'
-#' task <- sim_dgp_correlated(n = 500)
+#' task <- sim_dgp_correlated(n = 200)
 #'
 #' # Using default ConditionalARFSampler
 #' cfi <- CFI$new(
 #'   task = task,
-#'   learner = lrn("regr.ranger", num.trees = 10),
-#'   measure = msr("regr.mse")
+#'   learner = lrn("regr.rpart"),
+#'   measure = msr("regr.mse"),
+#'   sampler = ConditionalGaussianSampler$new(task),
+#'   n_repeats = 5
 #' )
 #' cfi$compute()
 #' cfi$importance()
@@ -447,7 +497,7 @@ CFI = R6Class(
 			features = NULL,
 			groups = NULL,
 			relation = "difference",
-			n_repeats = 1L,
+			n_repeats = 30L,
 			batch_size = NULL,
 			sampler = NULL
 		) {
@@ -527,14 +577,16 @@ CFI = R6Class(
 #'
 #' @references `r print_bib("konig_2021")`
 #'
-#' @examplesIf requireNamespace("ranger", quietly = TRUE) && requireNamespace("mlr3learners", quietly = TRUE) && requireNamespace("arf", quietly = TRUE)
+#' @examples
 #' library(mlr3)
 #' task = tgen("friedman1")$generate(n = 200)
 #' rfi = RFI$new(
 #'   task = task,
-#'   learner = lrn("regr.ranger", num.trees = 50),
+#'   learner = lrn("regr.rpart"),
 #'   measure = msr("regr.mse"),
-#'   conditioning_set = c("important1")
+#'   conditioning_set = c("important1"),
+#'   sampler = ConditionalGaussianSampler$new(task),
+#'   n_repeats = 5
 #' )
 #' rfi$compute()
 #' rfi$importance()
@@ -558,7 +610,7 @@ RFI = R6Class(
 			groups = NULL,
 			conditioning_set = NULL,
 			relation = "difference",
-			n_repeats = 1L,
+			n_repeats = 30L,
 			batch_size = NULL,
 			sampler = NULL
 		) {
