@@ -153,10 +153,10 @@ SAGE = R6Class(
 			check_interval = resolve_param(check_interval, self$param_set$values$check_interval, 1L)
 
 			# Initial resampling to get trained learners
-			rr = resample(
-				self$task,
-				self$learner,
-				self$resampling,
+			rr = assemble_rr(
+				task = self$task,
+				learner = self$learner,
+				resampling = self$resampling,
 				store_models = TRUE,
 				store_backends = store_backends
 			)
@@ -429,10 +429,6 @@ SAGE = R6Class(
 				# Update the count of completed permutations.
 				n_completed = n_completed + checkpoint_size
 
-				# if (n_completed > 2) {
-				# 	browser()
-				# }
-
 				# Calculate the current average SAGE values and standard errors based on completed permutations.
 				current_avg = sage_values / n_completed
 
